use std::collections::HashMap;

use lazy_static::lazy_static;

lazy_static! {
    pub static ref SYSCALLS: HashMap<usize, &'static str> = {
        let mut m = HashMap::new();

        m.insert(0, "RESTART_SYSCALL");
        m.insert(1, "EXIT");
        m.insert(2, "FORK");
        m.insert(3, "READ");
        m.insert(4, "WRITE");
        m.insert(5, "OPEN");
        m.insert(6, "CLOSE");
        m.insert(8, "CREAT");
        m.insert(9, "LINK");
        m.insert(10, "UNLINK");
        m.insert(11, "EXECVE");
        m.insert(12, "CHDIR");
        m.insert(14, "MKNOD");
        m.insert(15, "CHMOD");
        m.insert(16, "LCHOWN");

        m.insert(19, "LSEEK");
        m.insert(20, "GETPID");
        m.insert(21, "MOUNT");
        m.insert(23, "SETUID");
        m.insert(24, "GETUID");
        m.insert(26, "PTRACE");

        m.insert(29, "PAUSE");

        m.insert(33, "ACCESS");
        m.insert(34, "NICE");

        m.insert(36, "SYNC");
        m.insert(37, "KILL");
        m.insert(38, "RENAME");
        m.insert(39, "MKDIR");
        m.insert(40, "RMDIR");
        m.insert(41, "DUP");
        m.insert(42, "PIPE");
        m.insert(43, "TIMES");

        m.insert(45, "BRK");
        m.insert(46, "SETGID");
        m.insert(47, "GETGID");

        m.insert(49, "GETEUID");
        m.insert(50, "GETEGID");
        m.insert(51, "ACCT");
        m.insert(52, "UMOUNT2");

        m.insert(54, "IOCTL");
        m.insert(55, "FCNTL");

        m.insert(57, "SETPGID");

        m.insert(60, "UMASK");
        m.insert(61, "CHROOT");
        m.insert(62, "USTAT");
        m.insert(63, "DUP2");
        m.insert(64, "GETPPID");
        m.insert(65, "GETPGRP");
        m.insert(66, "SETSID");
        m.insert(67, "SIGACTION");

        m.insert(70, "SETREUID");
        m.insert(71, "SETREGID");
        m.insert(72, "SIGSUSPEND");
        m.insert(73, "SIGPENDING");
        m.insert(74, "SETHOSTNAME");
        m.insert(75, "SETRLIMIT");
        m.insert(77, "GETRUSAGE");
        m.insert(78, "GETTIMEOFDAY");
        m.insert(79, "SETTIMEOFDAY");
        m.insert(80, "GETGROUPS");
        m.insert(81, "SETGROUPS");
        m.insert(83, "SYMLINK");

        m.insert(85, "READLINK");
        m.insert(86, "USELIB");
        m.insert(87, "SWAPON");
        m.insert(88, "REBOOT");
        m.insert(91, "MUNMAP");
        m.insert(92, "TRUNCATE");
        m.insert(93, "FTRUNCATE");
        m.insert(94, "FCHMOD");
        m.insert(95, "FCHOWN");
        m.insert(96, "GETPRIORITY");
        m.insert(97, "SETPRIORITY");

        m.insert(99, "STATFS");
        m.insert(100, "FSTATFS");

        m.insert(103, "SYSLOG");
        m.insert(104, "SETITIMER");
        m.insert(105, "GETITIMER");
        m.insert(106, "STAT");
        m.insert(107, "LSTAT");
        m.insert(108, "FSTAT");

        m.insert(111, "VHANGUP");

        m.insert(114, "WAIT4");
        m.insert(115, "SWAPOFF");
        m.insert(116, "SYSINFO");
        m.insert(118, "FSYNC");
        m.insert(119, "SIGRETURN");
        m.insert(120, "CLONE");
        m.insert(121, "SETDOMAINNAME");
        m.insert(122, "UNAME");

        m.insert(124, "ADJTIMEX");
        m.insert(125, "MPROTECT");
        m.insert(126, "SIGPROCMASK");

        m.insert(128, "INIT_MODULE");
        m.insert(129, "DELETE_MODULE");

        m.insert(131, "QUOTACTL");
        m.insert(132, "GETPGID");
        m.insert(133, "FCHDIR");
        m.insert(134, "BDFLUSH");
        m.insert(135, "SYSFS");
        m.insert(136, "PERSONALITY");

        m.insert(138, "SETFSUID");
        m.insert(139, "SETFSGID");
        m.insert(140, "_LLSEEK");
        m.insert(141, "GETDENTS");
        m.insert(142, "_NEWSELECT");
        m.insert(143, "FLOCK");
        m.insert(144, "MSYNC");
        m.insert(145, "READV");
        m.insert(146, "WRITEV");
        m.insert(147, "GETSID");
        m.insert(148, "FDATASYNC");
        m.insert(149, "_SYSCTL");
        m.insert(150, "MLOCK");
        m.insert(151, "MUNLOCK");
        m.insert(152, "MLOCKALL");
        m.insert(153, "MUNLOCKALL");
        m.insert(154, "SCHED_SETPARAM");
        m.insert(155, "SCHED_GETPARAM");
        m.insert(156, "SCHED_SETSCHEDULER");
        m.insert(157, "SCHED_GETSCHEDULER");
        m.insert(158, "SCHED_YIELD");
        m.insert(159, "SCHED_GET_PRIORITY_MAX");
        m.insert(160, "SCHED_GET_PRIORITY_MIN");
        m.insert(161, "SCHED_RR_GET_INTERVAL");
        m.insert(162, "NANOSLEEP");
        m.insert(163, "MREMAP");
        m.insert(164, "SETRESUID");
        m.insert(165, "GETRESUID");

        m.insert(168, "POLL");
        m.insert(169, "NFSSERVCTL");
        m.insert(170, "SETRESGID");
        m.insert(171, "GETRESGID");
        m.insert(172, "PRCTL");
        m.insert(173, "RT_SIGRETURN");
        m.insert(174, "RT_SIGACTION");
        m.insert(175, "RT_SIGPROCMASK");
        m.insert(176, "RT_SIGPENDING");
        m.insert(177, "RT_SIGTIMEDWAIT");
        m.insert(178, "RT_SIGQUEUEINFO");
        m.insert(179, "RT_SIGSUSPEND");
        m.insert(180, "PREAD64");
        m.insert(181, "PWRITE64");
        m.insert(182, "CHOWN");
        m.insert(183, "GETCWD");
        m.insert(184, "CAPGET");
        m.insert(185, "CAPSET");
        m.insert(186, "SIGALTSTACK");
        m.insert(187, "SENDFILE");

        m.insert(190, "VFORK");
        m.insert(191, "UGETRLIMIT");
        m.insert(192, "MMAP2");
        m.insert(193, "TRUNCATE64");
        m.insert(194, "FTRUNCATE64");
        m.insert(195, "STAT64");
        m.insert(196, "LSTAT64");
        m.insert(197, "FSTAT64");
        m.insert(198, "LCHOWN32");
        m.insert(199, "GETUID32");
        m.insert(200, "GETGID32");
        m.insert(201, "GETEUID32");
        m.insert(202, "GETEGID32");
        m.insert(203, "SETREUID32");
        m.insert(204, "SETREGID32");
        m.insert(205, "GETGROUPS32");
        m.insert(206, "SETGROUPS32");
        m.insert(207, "FCHOWN32");
        m.insert(208, "SETRESUID32");
        m.insert(209, "GETRESUID32");
        m.insert(210, "SETRESGID32");
        m.insert(211, "GETRESGID32");
        m.insert(212, "CHOWN32");
        m.insert(213, "SETUID32");
        m.insert(214, "SETGID32");
        m.insert(215, "SETFSUID32");
        m.insert(216, "SETFSGID32");
        m.insert(217, "GETDENTS64");
        m.insert(218, "PIVOT_ROOT");
        m.insert(219, "MINCORE");
        m.insert(220, "MADVISE");
        m.insert(221, "FCNTL64");

        m.insert(224, "GETTID");
        m.insert(225, "READAHEAD");
        m.insert(226, "SETXATTR");
        m.insert(227, "LSETXATTR");
        m.insert(228, "FSETXATTR");
        m.insert(229, "GETXATTR");
        m.insert(230, "LGETXATTR");
        m.insert(231, "FGETXATTR");
        m.insert(232, "LISTXATTR");
        m.insert(233, "LLISTXATTR");
        m.insert(234, "FLISTXATTR");
        m.insert(235, "REMOVEXATTR");
        m.insert(236, "LREMOVEXATTR");
        m.insert(237, "FREMOVEXATTR");
        m.insert(238, "TKILL");
        m.insert(239, "SENDFILE64");
        m.insert(240, "FUTEX");
        m.insert(241, "SCHED_SETAFFINITY");
        m.insert(242, "SCHED_GETAFFINITY");
        m.insert(243, "IO_SETUP");
        m.insert(244, "IO_DESTROY");
        m.insert(245, "IO_GETEVENTS");
        m.insert(246, "IO_SUBMIT");
        m.insert(247, "IO_CANCEL");
        m.insert(248, "EXIT_GROUP");
        m.insert(249, "LOOKUP_DCOOKIE");
        m.insert(250, "EPOLL_CREATE");
        m.insert(251, "EPOLL_CTL");
        m.insert(252, "EPOLL_WAIT");
        m.insert(253, "REMAP_FILE_PAGES");

        m.insert(256, "SET_TID_ADDRESS");
        m.insert(257, "TIMER_CREATE");
        m.insert(258, "TIMER_SETTIME");
        m.insert(259, "TIMER_GETTIME");
        m.insert(260, "TIMER_GETOVERRUN");
        m.insert(261, "TIMER_DELETE");
        m.insert(262, "CLOCK_SETTIME");
        m.insert(263, "CLOCK_GETTIME");
        m.insert(264, "CLOCK_GETRES");
        m.insert(265, "CLOCK_NANOSLEEP");
        m.insert(266, "STATFS64");
        m.insert(267, "FSTATFS64");
        m.insert(268, "TGKILL");
        m.insert(269, "UTIMES");
        m.insert(270, "ARM_FADVISE64_64");
        m.insert(271, "PCICONFIG_IOBASE");
        m.insert(272, "PCICONFIG_READ");
        m.insert(273, "PCICONFIG_WRITE");
        m.insert(274, "MQ_OPEN");
        m.insert(275, "MQ_UNLINK");
        m.insert(276, "MQ_TIMEDSEND");
        m.insert(277, "MQ_TIMEDRECEIVE");
        m.insert(278, "MQ_NOTIFY");
        m.insert(279, "MQ_GETSETATTR");
        m.insert(280, "WAITID");
        m.insert(281, "SOCKET");
        m.insert(282, "BIND");
        m.insert(283, "CONNECT");
        m.insert(284, "LISTEN");
        m.insert(285, "ACCEPT");
        m.insert(286, "GETSOCKNAME");
        m.insert(287, "GETPEERNAME");
        m.insert(288, "SOCKETPAIR");
        m.insert(289, "SEND");
        m.insert(290, "SENDTO");
        m.insert(291, "RECV");
        m.insert(292, "RECVFROM");
        m.insert(293, "SHUTDOWN");
        m.insert(294, "SETSOCKOPT");
        m.insert(295, "GETSOCKOPT");
        m.insert(296, "SENDMSG");
        m.insert(297, "RECVMSG");
        m.insert(298, "SEMOP");
        m.insert(299, "SEMGET");
        m.insert(300, "SEMCTL");
        m.insert(301, "MSGSND");
        m.insert(302, "MSGRCV");
        m.insert(303, "MSGGET");
        m.insert(304, "MSGCTL");
        m.insert(305, "SHMAT");
        m.insert(306, "SHMDT");
        m.insert(307, "SHMGET");
        m.insert(308, "SHMCTL");
        m.insert(309, "ADD_KEY");
        m.insert(310, "REQUEST_KEY");
        m.insert(311, "KEYCTL");
        m.insert(312, "SEMTIMEDOP");
        m.insert(313, "VSERVER");
        m.insert(314, "IOPRIO_SET");
        m.insert(315, "IOPRIO_GET");
        m.insert(316, "INOTIFY_INIT");
        m.insert(317, "INOTIFY_ADD_WATCH");
        m.insert(318, "INOTIFY_RM_WATCH");
        m.insert(319, "MBIND");
        m.insert(320, "GET_MEMPOLICY");
        m.insert(321, "SET_MEMPOLICY");
        m.insert(322, "OPENAT");
        m.insert(323, "MKDIRAT");
        m.insert(324, "MKNODAT");
        m.insert(325, "FCHOWNAT");
        m.insert(326, "FUTIMESAT");
        m.insert(327, "FSTATAT64");
        m.insert(328, "UNLINKAT");
        m.insert(329, "RENAMEAT");
        m.insert(330, "LINKAT");
        m.insert(331, "SYMLINKAT");
        m.insert(332, "READLINKAT");
        m.insert(333, "FCHMODAT");
        m.insert(334, "FACCESSAT");
        m.insert(335, "PSELECT6");
        m.insert(336, "PPOLL");
        m.insert(337, "UNSHARE");
        m.insert(338, "SET_ROBUST_LIST");
        m.insert(339, "GET_ROBUST_LIST");
        m.insert(340, "SPLICE");
        m.insert(341, "ARM_SYNC_FILE_RANGE");
        m.insert(341, "SYNC_FILE_RANGE2");
        m.insert(342, "TEE");
        m.insert(343, "VMSPLICE");
        m.insert(344, "MOVE_PAGES");
        m.insert(345, "GETCPU");
        m.insert(346, "EPOLL_PWAIT");
        m.insert(347, "KEXEC_LOAD");
        m.insert(348, "UTIMENSAT");
        m.insert(349, "SIGNALFD");
        m.insert(350, "TIMERFD_CREATE");
        m.insert(351, "EVENTFD");
        m.insert(352, "FALLOCATE");
        m.insert(353, "TIMERFD_SETTIME");
        m.insert(354, "TIMERFD_GETTIME");
        m.insert(355, "SIGNALFD4");
        m.insert(356, "EVENTFD2");
        m.insert(357, "EPOLL_CREATE1");
        m.insert(358, "DUP3");
        m.insert(359, "PIPE2");
        m.insert(360, "INOTIFY_INIT1");
        m.insert(361, "PREADV");
        m.insert(362, "PWRITEV");
        m.insert(363, "RT_TGSIGQUEUEINFO");
        m.insert(364, "PERF_EVENT_OPEN");
        m.insert(365, "RECVMMSG");
        m.insert(366, "ACCEPT4");
        m.insert(367, "FANOTIFY_INIT");
        m.insert(368, "FANOTIFY_MARK");
        m.insert(369, "PRLIMIT64");
        m.insert(370, "NAME_TO_HANDLE_AT");
        m.insert(371, "OPEN_BY_HANDLE_AT");
        m.insert(372, "CLOCK_ADJTIME");
        m.insert(373, "SYNCFS");
        m.insert(374, "SENDMMSG");
        m.insert(375, "SETNS");
        m.insert(376, "PROCESS_VM_READV");
        m.insert(377, "PROCESS_VM_WRITEV");
        m.insert(378, "KCMP");
        m.insert(379, "FINIT_MODULE");
        m.insert(380, "SCHED_SETATTR");
        m.insert(381, "SCHED_GETATTR");
        m.insert(382, "RENAMEAT2");
        m.insert(383, "SECCOMP");
        m.insert(384, "GETRANDOM");
        m.insert(385, "MEMFD_CREATE");
        m.insert(386, "BPF");
        m.insert(387, "EXECVEAT");

        m
    };
}
